@@ -21,8 +21,8 @@
  * @author Sam Meder
  * 
  * $RCSfile: globus_gsi_cert_utils.c,v $
- * $Revision: 1.33 $
- * $Date: 2011/01/28 02:21:23 $
+ * $Revision: 1.33.14.3 $
+ * $Date: 2013/10/10 17:29:12 $
  *
  */
 #endif
@@ -33,6 +33,7 @@
 #include "openssl/asn1.h"
 #include "openssl/x509.h"
 #include "openssl/x509v3.h"
+#include "openssl/pem.h"
 #include "version.h"
 #include "config.h"
 #include <ctype.h>
@@ -887,7 +888,7 @@ globus_gsi_cert_utils_get_eec(
  *
  * @param cert_chain
  *    Certificate chain to inspect.
- * @param eec
+ * @param identity_cert
  *    Pointer to be set to the certificate value from within the cert chain.
  *    Must freed by the caller.
  */
